@@ -224,7 +224,14 @@ class ADBClient(object):
 
     def which(self, command: str) -> Optional[str]:
         self._connect_if_disconnected()
-        return adb_connection.which(command=command, ip=self._identifier)
+        if self.hash_which():
+            return adb_connection.which(command=command, ip=self._identifier)
+        elif self.has_busybox():
+            result = self.busybox(f"which {command}")
+            if result.is_ok():
+                return result.output()
+        else:
+            return None
 
     def ls(self, dirname: str, **kwargs):
         args = adb_connection.expand_extra_arguments(**kwargs)
